# Change Log

## [2019.0910]

  - Use new `xcamera` from PyPI
  - Use `opencv-python` from PyPI, refs #23

## [2019.0909]

  - Fix camera events not binded
  - Makefile improvements
  - Bump to Kivy==1.11.1, refs #22

## [2019.0907]

  - Update buildozer, p4a, and ndk versions, refs #21
  - Publish to F-Droid, refs #20
  - Improve Android camera permission handling, refs #12, #16
  - Use upstream autofocus, refs #8

## [2019.0902]

  - Update Cython for Python3.7 support, refs #35
  - Make garden.zbarcam a package again, refs #36
  - Don't ship opencv directory to APK, refs #37
  - Migrate to new garden structure, refs #17
  - Publish documentation to readthedocs, refs #18
  - Publish to PyPI, refs #19

## [2019.0303]

  - Add Python3.6 support, refs #5
  - Fully migrated Android from PIL to Pillow, refs #13
  - Handle Android runtime permissions, refs #30
  - Fixe codes not detected on Android, refs #32
  - Migrate from zbarlight to pyzbar, refs #32
  - Migrate to Python3.6 and opencv 4, refs #33

## [2019.0223]

  - Fix zbarlight dependency in setup.py, refs #28
  - Migrate to zbarlight 2.1, refs #18

## [2019.0222]

  - Provide Makefile, refs #15
  - Setup continuous integration testing, refs #6, #14
  - Speedup OpenCV compilation time, refs #16
  - Migrated to zbarlight, refs #5, #13
  - Introduced UI tests, refs #4
  - Using non-root Docker container, refs #27
  - Run UI tests from Travis, refs #26

## [2017.1220]

  - Full screen camera
  - Kvlang refactoring
  - File tree refactoring

## [2017.1117]

  - Integrated to kivy-garden

## [2017.1102]

  - Add camera start/stop

## [2017.1020]

  - Add Android autofocus, refs #2
  - Fix Android rotation, refs #3
  - Add animated demo gif

## [2017.1019]

  - Add ZBar Android support, refs #1
  - Add PIL/Pillow Android workaround

## [2017.1016]

  - Initial release
